@@ -1,6 +1,6 @@
 from quasinet.qnet import Qnet, load_qnet, save_qnet
 from quasinet.qnet import export_qnet_tree, export_qnet_graph
-from util import assert_None
+from cognet.util import assert_None
 class model:
     """Facilitate training and constructing Qnet
     """
@@ -95,4 +95,4 @@ class model:
         else:
             for i in index:
                 export_qnet_tree(self.myQnet,
-                                 i, filename)
\ No newline at end of file
+                                 i, filename)
